%> @file PlcReal.m
% This file is protected by TIS
% Copyright  2013-2022.

% PlcReal
%>   Represents a single value (in PLC a REAL) its value defines a single-precision floating-point number.
classdef PlcReal < PlcValue    
    % ---------- Public properties ----------
    properties (Access = public, Dependent = true)
        %> @brief Gets or sets the value assigned to the PLC value.
        %>   The value assigned to the PLC value.
        Value;
    end % properties

    % ---------- Public constructors ----------
    methods (Access = public)
        %> @brief Initializes a new instance of the PlcReal class using the specified @b address and @b value.
        %>
        %> @param address The PlcAddress of the new PlcReal to which the PLC
        %>                value belongs.
        %> @param value The initial value of the new PlcReal.
        %>
        %> @b Errors
        %> * The @b address does not refer to the @b PlcRawType.DWord.
        function this = PlcReal(address, value)
            superArguments{1} = PlcTypeCode.Real;
            superArguments{2} = address;
            superArguments{3} = 0; % Length

            if (nargin == 2)
                superArguments{4} = System.Convert.ToSingle(value);
            else
                superArguments{4} = System.Convert.ToSingle(0.0);
            end

            this = this@PlcValue( ...
                    superArguments{1}, ...
                    superArguments{2}, ...
                    superArguments{3}, ...
                    superArguments{4});
        end
    end % methods

    % ---------- Property accessors ----------
    methods
        %> Gets the value assigned to the PLC value.
        function value = get.Value(this)
            value = this.ManagedInstance.GetValue('Value');
        end

        %> Sets the value assigned to the PLC value.
        function set.Value(this, value)
            this.ManagedInstance.SetValue('Value', System.Convert.ToSingle(value));
        end
    end % methods
end

